/* exported init */
/* exported buildPrefsWidget */

'use strict';

const ExtensionUtils = imports.misc.extensionUtils;

const { Gio, GObject, Gtk } = imports.gi;

const PREFS_MARGIN = 15;
const PREFS_SPACING = 5;


function _buildPrefEntry(settings, settingsLabel, settingsKey) {
	const box = new Gtk.Box({ orientation: Gtk.Orientation.HORIZONTAL });
	const label = new Gtk.Label({ label: settingsLabel, xalign: 0 });
	const entry = new Gtk.Entry({ text: settings.get_string(settingsKey) });

	settings.bind(settingsKey, entry.buffer, 'text', Gio.SettingsBindFlags.DEFAULT);

	entry.set_icon_from_icon_name(Gtk.EntryIconPosition.SECONDARY, "document-revert");
	entry.connect("icon-press", () => {
		settings.reset(settingsKey);
		entry.buffer.text = settings.get_string(settingsKey);
	});

	box.pack_start(label, true, true, 0);
	box.pack_start(entry, false, false, 0);

	return box;
}


const LatencyMonitorPrefsWidget = GObject.registerClass(
	class LatencyMonitorPrefsWidget extends Gtk.Notebook {
		_init() {
			super._init();

			this.settings = ExtensionUtils.getSettings("org.gnome.shell.extensions.latency-monitor");

			this.append_page(this._buildLatencyPage(), Gtk.Label.new("Latency"));
		}

		_buildLatencyPage() {
			const page = new Gtk.Box({ orientation: Gtk.Orientation.VERTICAL, margin: PREFS_MARGIN, margin_top: PREFS_MARGIN - PREFS_SPACING });

			const pingDestinationPref = _buildPrefEntry(this.settings, "Ping Destination", "ping-destination");
			page.pack_start(pingDestinationPref, false, false, PREFS_SPACING);

			return page;
		}
	}
);


function init() { }

function buildPrefsWidget() {
	let prefsWidget = new LatencyMonitorPrefsWidget();
	prefsWidget.show_all();
	return prefsWidget;
}
